ConsentStatus class

Constructors

ConsentStatus({int? consentPurposeId, String? consentPurposeName, bool? consentStatus, String? frequency, int? piiLabelId, String? piiLabelName, int? consentLifetime})
ConsentStatus.fromJson(Map<String, dynamic> json)

Properties

consentLifetime int?
getter/setter pair
consentPurposeId int?
getter/setter pair
consentPurposeName String?
getter/setter pair
consentStatus bool?
getter/setter pair
frequency String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
piiLabelId int?
getter/setter pair
piiLabelName String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited