ConsentFormScreenState class
- Inheritance
-
- Mixed-in types
-
Methods
-
activate()
→ void
-
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(BuildContext context)
→ Widget
-
Describes the part of the user interface represented by this widget.
override
-
deactivate()
→ void
-
Called when this object is removed from the tree.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
didChangeDependencies()
→ void
-
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(covariant ConsentFormScreen oldWidget)
→ void
-
Called whenever the widget configuration changes.
inherited
-
dispose()
→ void
-
Called when this object is removed from the tree permanently.
inherited
-
initState()
→ void
-
Called when this object is inserted into the tree.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
parseConsentData(ConsentFormResponse consentData)
→ CustomerData
-
-
reassemble()
→ void
-
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
setConsentData(ConsentFormResponse data, FrequencyResponse freqData, WidgetRef ref, LangResponse langResponse)
→ Widget
-
-
setState(VoidCallback fn)
→ void
-
Notify the framework that the internal state of this object has changed.
inherited
-
showConfirmationDialog({required BuildContext context, required String message, String title = 'Confirmation', String confirmText = 'Yes', String cancelText = 'No', VoidCallback? onConfirm, VoidCallback? onCancel})
→ void
-
Shows a confirmation dialog with Yes and No buttons
inherited
-
showCustomDialog({required BuildContext context, Widget? title, Widget? content, List<Widget>? actions})
→ void
-
Shows a custom dialog with fully customizable widgets
inherited
-
showInfoDialog({required BuildContext context, required String message, String title = 'Info', String buttonText = 'OK', VoidCallback? onOkPressed})
→ void
-
Shows an information dialog with a single OK button
inherited
-
showProgressDialog(BuildContext context)
→ void
-
inherited
-
showSuccessDialog(BuildContext context, {String message = "Record created successfully!"})
→ void
-
inherited
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringShort()
→ String
-
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
validateFields(ConsentFormResponse data)
→ bool
-