ConsentStatus class

Constructors

ConsentStatus({int? collectionTemplateId, int? consentLifetime, int? consentPurposeId, String? consentPurposeName, bool? consentStatus, int? dataPrincipalId, String? frequency, int? piiLabelId, int? processingPurposeId})
ConsentStatus.fromJson(Map<String, dynamic> json)

Properties

collectionTemplateId int?
getter/setter pair
consentLifetime int?
getter/setter pair
consentPurposeId int?
getter/setter pair
consentPurposeName String?
getter/setter pair
consentStatus bool?
getter/setter pair
dataPrincipalId int?
getter/setter pair
frequency String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
piiLabelId int?
getter/setter pair
processingPurposeId int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited