BasicInfo class

Constructors

BasicInfo({String? title, String? description, String? privacy_notice_heading, String? preference_center_heading, String? dsr_center_heading})
BasicInfo.fromJson(Map<String, dynamic> json)

Properties

description String?
getter/setter pair
dsr_center_heading String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
preference_center_heading String?
getter/setter pair
privacy_notice_heading String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited