ConsentListPref class

Constructors

ConsentListPref({int? id, int? consentPurposeId, String? consentPurposeName, int? piiLabelId, String? piiLabelName, String? frequency, dynamic consentLifetime, dynamic consentExpiration, bool? defaultOptOutAllowed, bool? compulsoryConsent, bool? consentStatus, bool? status, String? createdAt, String? updatedAt, int? processingPurposeId, int? collectionTemplateId})
ConsentListPref.fromJson(Map<String, dynamic> json)

Properties

collectionTemplateId int?
getter/setter pair
compulsoryConsent bool?
getter/setter pair
consentExpiration ↔ dynamic
getter/setter pair
consentLifetime ↔ dynamic
getter/setter pair
consentPurposeId int?
getter/setter pair
consentPurposeName String?
getter/setter pair
consentStatus bool?
getter/setter pair
createdAt String?
getter/setter pair
defaultOptOutAllowed bool?
getter/setter pair
frequency String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
getter/setter pair
piiLabelId int?
getter/setter pair
piiLabelName String?
getter/setter pair
processingPurposeId int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status bool?
getter/setter pair
updatedAt String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited