Data class
Constructors
-
Data({AdditionalInfo? additionalInfo, BasicInfo? basicInfo, PreferenceCenterConfiguration? preferenceCenterConfiguration, List<
PrivacyNote> ? privacyNote, Dsr? dsr, List<UcmPreferenceForm> ? ucmPreferenceForm}) -
Data.fromJson(Map<
String, dynamic> json)
Properties
- additionalInfo ↔ AdditionalInfo?
-
getter/setter pair
- basicInfo ↔ BasicInfo?
-
getter/setter pair
- dsr ↔ Dsr?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- preferenceCenterConfiguration ↔ PreferenceCenterConfiguration?
-
getter/setter pair
-
privacyNote
↔ List<
PrivacyNote> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
ucmPreferenceForm
↔ List<
UcmPreferenceForm> ? -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited