PurposeList class
Constructors
-
PurposeList({int? processingPurposeId, String? processingPurposeName, List<
ConsentListPref> ? consentList}) -
PurposeList.fromJson(Map<
String, dynamic> json)
Properties
-
consentList
↔ List<
ConsentListPref> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- processingPurposeId ↔ int?
-
getter/setter pair
- processingPurposeName ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited