CustomerData class
Constructors
-
CustomerData({int? customerId, int? collectionTemplateId, String? consentSource, String? geolocation, String? continent, int? subjectIdentityId, String? subjectIdentityValue, String? subjectIdentityName, String? verificationKey, List<
PiiData> ? piiData, List<ConsentStatus> ? consentStatus}) -
CustomerData.fromJson(Map<
String, dynamic> json)
Properties
- collectionTemplateId ↔ int?
-
getter/setter pair
- consentSource ↔ String?
-
getter/setter pair
-
consentStatus
↔ List<
ConsentStatus> ? -
getter/setter pair
- continent ↔ String?
-
getter/setter pair
- customerId ↔ int?
-
getter/setter pair
- geolocation ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
piiData
↔ List<
PiiData> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subjectIdentityId ↔ int?
-
getter/setter pair
- subjectIdentityName ↔ String?
-
getter/setter pair
- subjectIdentityValue ↔ String?
-
getter/setter pair
- verificationKey ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited