AdditionalInfo class
Constructors
- AdditionalInfo({int? preferenceCenterId, int? customerId, int? subjectIdentityTypeId, String? subjectIdentityTypeName, int? entityId, String? url, bool? status, String? verificationKey, dynamic redirectURL, bool? isPublished, String? publishedAt, String? createdAt, String? updatedAt})
-
AdditionalInfo.fromJson(Map<
String, dynamic> json)
Properties
- createdAt ↔ String?
-
getter/setter pair
- customerId ↔ int?
-
getter/setter pair
- entityId ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPublished ↔ bool?
-
getter/setter pair
- preferenceCenterId ↔ int?
-
getter/setter pair
- publishedAt ↔ String?
-
getter/setter pair
- redirectURL ↔ dynamic
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ bool?
-
getter/setter pair
- subjectIdentityTypeId ↔ int?
-
getter/setter pair
- subjectIdentityTypeName ↔ String?
-
getter/setter pair
- updatedAt ↔ String?
-
getter/setter pair
- url ↔ String?
-
getter/setter pair
- verificationKey ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited