PreferenceCenterConfiguration class
Constructors
- PreferenceCenterConfiguration({String? fontFamily, String? logoUrl, bool? showLogo, bool? showCookie, bool? showConsent, bool? showDSR, String? title, String? description, String? dsrContent, String? privacy_notice_heading, String? preference_center_heading, String? dsr_center_heading})
-
PreferenceCenterConfiguration.fromJson(Map<
String, dynamic> json)
Properties
- description ↔ String?
-
getter/setter pair
- dsr_center_heading ↔ String?
-
getter/setter pair
- dsrContent ↔ String?
-
getter/setter pair
- fontFamily ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- logoUrl ↔ String?
-
getter/setter pair
- preference_center_heading ↔ String?
-
getter/setter pair
- privacy_notice_heading ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showConsent ↔ bool?
-
getter/setter pair
- showCookie ↔ bool?
-
getter/setter pair
- showDSR ↔ bool?
-
getter/setter pair
- showLogo ↔ bool?
-
getter/setter pair
- title ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited