UcmPreferenceForm class
Constructors
-
UcmPreferenceForm({int? collectionTemplateId, String? collectionTemplateName, int? dataPrincipalId, List<
PurposeList> ? purposeList}) -
UcmPreferenceForm.fromJson(Map<
String, dynamic> json)
Properties
- collectionTemplateId ↔ int?
-
getter/setter pair
- collectionTemplateName ↔ String?
-
getter/setter pair
- dataPrincipalId ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
purposeList
↔ List<
PurposeList> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited